﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Infragistics.UltraChart.Data;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Resources.Appearance;
using System.Data;

public partial class _Default : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        //Setup DataSource
        Array dataList = Array.CreateInstance(typeof(MyData), 5);
        for (int i = 0; i < 5; i++)
        {
            dataList.SetValue(new MyData(DateTime.Now.AddMonths(i), (double)(i * 10 + i * 0.1)), i);
        }

        DataTable table = new DataTable();
        table.Columns.Add("Date", typeof(DateTime));
        table.Columns.Add("Value", typeof(double));

        double minValue = 0;
        double maxValue = 0;

        foreach (MyData data in dataList)
        {
            table.Rows.Add(new object[] { data.Date, data.Value });
            if (data.Value > 0 && data.Value > maxValue)
            {
                maxValue = data.Value;
            }
            if (data.Value < 0 && data.Value < minValue)
            {
                minValue = data.Value;
            }
        }

        NumericTimeSeries series = new NumericTimeSeries();
        series.Data.TimeValueColumn = "Date";
        series.Data.ValueColumn = "Value";
        series.Data.DataSource = table;
        series.DataBind();
        this.UltraChart1.Series.Add(series);

        //Setup Chart
        this.UltraChart1.ChartType = ChartType.ScatterChart;
        this.UltraChart1.ScatterChart.ConnectWithLines = true;
        this.UltraChart1.ScatterChart.LineAppearance.SplineTension = 0;
        this.UltraChart1.Data.UseMinMax = true;
        this.UltraChart1.Data.ZeroAligned = true;
        this.UltraChart1.Tooltips.FormatString = "Run DateTime : <DATA_VALUE_X:dd-MM-yyyy HH:mm>\r\n" + "Value : <DATA_VALUE_Y:##.##>mm";
        this.UltraChart1.ScatterChart.Icon = SymbolIcon.Circle;
        this.UltraChart1.ScatterChart.IconSize = SymbolIconSize.Medium;

        //Setup X Axis
        this.UltraChart1.Axis.X.Labels.ItemFormatString = "<DATA_VALUE:MMM-yyyy>";
        this.UltraChart1.Axis.X.LineThickness = 1;
        this.UltraChart1.Axis.X.Labels.ItemFormat = AxisItemLabelFormat.Custom;
        this.UltraChart1.Axis.X.Labels.Orientation = TextOrientation.Horizontal;
        this.UltraChart1.Axis.X.TickmarkStyle = AxisTickStyle.Smart;
        this.UltraChart1.Axis.X.TimeAxisStyle.TimeAxisStyle = RulerGenre.Continuous;
        this.UltraChart1.Axis.X.Labels.Orientation = TextOrientation.VerticalLeftFacing;

        //Setup Y Axis
        this.UltraChart1.Axis.Y.Labels.ItemFormatString = "<DATA_VALUE:n2>";
        this.UltraChart1.Axis.Y.LineThickness = 1;
        this.UltraChart1.Axis.Y.Labels.ItemFormat = AxisItemLabelFormat.Custom;
        this.UltraChart1.Axis.Y.Labels.Orientation = TextOrientation.Horizontal;
        this.UltraChart1.Axis.Y.RangeType = AxisRangeType.Custom;
        this.UltraChart1.Axis.Y.RangeMin = minValue;         //Calculate during datasource creation!
        this.UltraChart1.Axis.Y.RangeMax = maxValue;       //Calculate during datasource creation!
        

        ////Setup Item Labels
        //this.UltraChart1.ScatterChart.ChartText[0].Visible = true;
        //this.UltraChart1.ScatterChart.ChartText[0].Column = -2;
        //this.UltraChart1.ScatterChart.ChartText[0].Row = -2;
        //this.UltraChart1.ScatterChart.ChartText[0].ItemFormatString = "<ITEM_LABEL:##.##>mm";


        //UltraChart2.DataSource = DemoTable.Table();
        //UltraChart2.DataBind();
    }

    class MyData
    {
        public MyData(DateTime date, double value)
        {
            this.date = date;
            this.value = value;
        }

        private DateTime date;
        public DateTime Date
        {
            get
            {
                return this.date;
            }
            set
            {
                this.date = value;
            }
        }

        private double value;
        public double Value
        {
            get
            {
                return this.value;
            }
            set
            {
                this.value = value;
            }
        }
    }
}
